import React from 'react';
import { UploadOutlined } from '@ant-design/icons'
import { Button, Space, Row, Col, Popconfirm } from 'antd';
import Upload from './Upload'

const noop = x => x;

export default function UploadFiles (props) {

  const {
    rowKey = "id",
    rowLabel = "attachName",
    readonly = false,
    multiple = true,
    value,
    onChange,
    onPreview,
    onDownload,
    transform = noop,
    renderItem = defRenderItem,
    ...leftProps
  } = props;

  const [loading, setLoading] = React.useState(false)

  const list = React.useMemo(() => {
    return Array.isArray(value) ? value.filter(Boolean) : [value].filter(Boolean);
  }, [value]);

  const getId = (item) => {
    return typeof rowKey == 'function' ? rowKey(item) : item[rowKey];
  };

  const getLabel = (item) => {
    return typeof rowLabel == 'function' ? rowLabel(item) : item[rowLabel];
  }

  const handleChange = (info) => {
    // console.log('info-------->', info)
    if (info.file.status === 'uploading') {
      setLoading(true)
      return
    }
    if (info.file.status === 'error') {
      setLoading(false)
      return
    }

    if (info.file.status === 'done') {
      setLoading(false)
      const resp = info.file.response;
      const data = typeof transform == 'function' ? transform(resp) : resp;
      // let da = data?.url
      if (multiple) {
        // console.log('-------2---->>');
        const idList = list.map(getId);
        const targId = getId(data);
        // if (idList.findIndex(x => x == targId) == -1) {
        let da = { ...data, status: 1 }
        const destList = list.map(item => {
          const { createdBy, createdTime, updatedBy, updatedTime, ...rest } = item;
          return rest;
        });
        onChange(destList.concat(da))
        // }
      } else {
        onChange(data)
      }
    }
  }

  const onDelete = (item) => {
    if (multiple) {
      const id = getId(item);
      const vals = list.filter(x => getId(x) != id);
      onChange(vals);
    } else {
      onChange();
    }
  }

  // console.log('-----valuefang--->', value);

  return (
    <Upload
      multiple={multiple}
      showUploadList={false}
      onChange={handleChange}
      style={{ display: 'inline-block', width: '100%' }}
      {...leftProps}
    >
      {!readonly && <Button icon={<UploadOutlined />}>上传附件</Button>}
      <div onClick={e => e.stopPropagation()} style={{ marginTop: 10 }}>
        {
          list.map(item => (
            <div key={getId(item)}>{renderItem(item, { readonly, loading, getLabel, getId, onDelete, onPreview, onDownload })}</div>
          ))
        }
      </div>
    </Upload>
  );
}

const btnStyle = { padding: 0, height: '24px' };

function defRenderItem (item, { readonly, loading, getLabel, getId, onDelete, onPreview, onDownload }) {

  const handlePreview = () => {
    if (typeof onPreview == 'function') {
      onPreview(item);
    }
  }

  const handleDownload = () => {
    if (typeof onDownload == 'function') {
      onDownload(item);
    }
  }

  return (
    <Row gutter={16}>
      <Col flex={1} style={{ display: 'flex', alignItems: 'center' }}>
        <div style={{ fontSize: '12px' }}>{getLabel(item)}</div>
      </Col>
      <Col flex="none">
        <Button type='link' style={btnStyle} onClick={handlePreview}>预览</Button>
      </Col>
      <Col flex="none">
        <Button type='link' style={btnStyle} onClick={handleDownload}>下载</Button>
      </Col>
      {
        !readonly ? (
          <Col flex="none">
            <Popconfirm
              title="确定进行删除操作 ?"
              onConfirm={() => onDelete(item)}
            >
              <Button type='link' style={btnStyle} danger>删除</Button>
            </Popconfirm>
          </Col>
        ) : null
      }
    </Row>
  );
}
