import React, { useRef, useState } from 'react'
import { Button, Input, Form, Select } from 'antd'
import Edit from '@/components/Page/Edit'
import Wangeditor from '@/components/Wangeditor'
import UploadFiles from '@/components/Upload/UploadFiles'
import UploadImages from '@/components/Upload/UploadImages'
import UploadImageList from '@/components/Upload/UploadImageList'
import { previewFile, downladFile } from '@/utils/attach';
import { getTaPostById, postTaPost, putTaPost } from "@/services/taPost";

const request = {
  get: getTaPostById,
  save: postTaPost,
  update: putTaPost,
}

export default (props) => {

  const transform = (_, item) => {
    let images = item?.images ? JSON.stringify(item?.images) : null
    let taAttachList = item?.taAttachList ? item?.taAttachList : []
    let tags = item?.tags ? JSON.stringify(item?.tags) : null
    let data = { ...item, images: images, taAttachList: taAttachList, tags: tags }
    return data
  }

  const convertValue = (formData) => {
    let tags = formData?.tags ? JSON.parse(formData?.tags) : null
    let images = formData?.images ? JSON.parse(formData?.images) : null
    return { ...formData, tags: tags, images: images }
  }

  return (
    <Edit
      rowKey="postId"
      request={request}
      transform={transform}
      convertValue={convertValue}
      // onValuesChange={console.log}
      renderItems={() => (
        <>
          <Form.Item label="文章标题" required name="title">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label="文章描述" name="describe">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label="文章正文" name="content">
            <Wangeditor />
          </Form.Item>
          <Form.Item label="文章图片" name="images">
            <UploadImageList />
          </Form.Item>
          <Form.Item label="横向封面" name="coverHorizontal">
            <UploadImages ratio={0.5} />
          </Form.Item>
          <Form.Item label="纵向封面" name="coverVertical">
            <UploadImages ratio={'100:200'} />
          </Form.Item>

          <Form.Item label="文章标签" name="tags">
            <Select mode="tags" tokenSeparators={[',']} placeholder="请输入" />
          </Form.Item>
          <Form.Item label="文章作者" name="author">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label="链接地址" name="link">
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label="上传附件" name="taAttachList">
            <UploadFiles
              rowKey={x => x.attachUrl}
              rowLabel={x => x.attachName}
              transform={x => ({ attachUrl: x.url, attachName: x.name, fileType: x.fileType })}
              onDownload={x => downladFile(x)}
              onPreview={x => previewFile(x)}
            />
          </Form.Item>
        </>
      )}
    />
  )
}