import React from "react";
import { Button, Card, Form, Input, InputNumber, Select } from "antd";
import useBool from "@/utils/hooks/useBool";
import { postTdCategory, putTdCategory } from "@/services/tdCategory";
import { formItemLayout, tailFormItemLayout } from "@/utils/form";

export default (props) => {
  const { category, list, parentId, onChange } = props;

  const [submiting, startSubmit, cancelSubmit] = useBool();
  const [form] = Form.useForm();

  const onFinish = (values) => {
    startSubmit();

    if (category?.categoryId) {
      // 修改
      putTdCategory(category.categoryId, values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    } else {
      // 新增
      postTdCategory(values)
        .then((res) => {
          cancelSubmit();
          onChange(res);
        })
        .catch(() => {
          cancelSubmit();
        });
    }
  };

  React.useEffect(() => {

    form.resetFields();
    if (category) {
      form.setFieldsValue(category);
    } else {
      form.setFieldValue("parentId", parentId);
    }

  }, [category, parentId]);

  return (
    <Form
      form={form}
      {...formItemLayout}
      style={{ maxWidth: "800px" }}
      onFinish={onFinish}
    >
      <Form.Item
        name="sortNo"
        label="序号"
      >
        <Input />
      </Form.Item>
      <Form.Item
        name="categoryName"
        label="分类"
        rules={[{ required: true, message: "请填写分类名称" }]}
      >
        <Input />
      </Form.Item>
      <Form.Item name="parentId" label="上级分类">
        <Select disabled={true}>
          {(list || []).map((x) => (
            <Select.Option key={x.categoryId}>{x.categoryName}</Select.Option>
          ))}
        </Select>
      </Form.Item>

      <Form.Item name="status" label="状态">
        <Select style={{ width: "100%" }} placeholder="请选择状态">
          <Select.Option value={0}>不正常</Select.Option>
          <Select.Option value={1}>正常</Select.Option>
        </Select>
      </Form.Item>
      <Form.Item {...tailFormItemLayout}>
        <Button loading={submiting} type="primary" htmlType="submit">
          保存
        </Button>
      </Form.Item>
    </Form>
  );
};
