import {
  UserOutlined,
  SolutionOutlined,
  FileTextOutlined,
  ContainerOutlined,
  EllipsisOutlined,
  StopFilled,
} from '@ant-design/icons'
import { Outlet, Navigate } from 'react-router-dom'
import AuthLayout from '@/layouts/AuthLayout'
import Login from '@/pages/login'
import Page404 from '@/pages/404'
import Article from '@/pages/article'
import ArticleEdit from '@/pages/article/Edit'
import ArticleDetail from '@/pages/article/detail'
import Classify from '@/pages/classify'
import PreviewObj from "@/pages/PreviewObj";

// import RoleEdit from "@/pages/role/Edit";
/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */

export const authRoutes = [
  {
    index: true,
    element: <Navigate to="/article" replace={true} />,
  },
  {
    path: 'article',
    element: <Article />,
    meta: {
      title: '文章管理',
      icon: <ContainerOutlined />,
    },
  },
  {
    path: 'article/edit',
    element: <ArticleEdit />,
    meta: {
      title: '文章维护',
      hideInMenu: true
    },
  },
  // {
  //   path: 'article/detail',
  //   element: <ArticleDetail />,
  //   meta: {
  //     title: '文章详情',
  //     hideInMenu: true
  //   },
  // },
  {
    path: 'classify',
    element: <Classify />,
    meta: {
      title: '分类管理',
      icon: <EllipsisOutlined />,
    },
  }
]

export const defaultRoutes = [
  {
    path: '/',
    element: <AuthLayout />,
    children: [
      {
        path: '*',
        element: <Page404 />,
      },
    ],
  },
  {
    path: "/previewobj",
    element: <PreviewObj />,
  },
  {
    path: '/login',
    element: <Login />,
  },
  {
    path: '*',
    element: <Page404 />,
  },
]

export function mergeAuthRoutes (r1, r2) {
  const r = r1.slice()
  const children = r1[0].children.slice()
  r[0].children = children.concat(r2)
  return r
}

// 全部路由
export const routes = mergeAuthRoutes(defaultRoutes, authRoutes)
function getPath (parent = '/', current = '') {
  if (current.indexOf('/') === 0 || current.indexOf('http') === 0)
    return current
  return `${parent}/${current}`.replace(/\/\//g, '/')
}

// 路由数组, 一维数组
export const routeArr = (() => {
  const flatten = (routes, parentPath = '/') => {
    return routes.reduce((acc, route) => {
      const path = getPath(parentPath, route.path)
      const children = route.children ? flatten(route.children, path) : []

      return acc.concat([{ ...route, path }].concat(children))
    }, [])
  }

  return flatten(routes)
})()
